/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task;

import com.nbtaskfocus.model.api.TaskList;
import com.nbtaskfocus.monitor.ContextListener;
import java.beans.PropertyChangeEvent;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.netbeans.api.project.FileOwnerQuery;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.util.Lookup;
import org.openide.windows.TopComponent;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class ContextListenerWrapper extends ContextListener {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.task");

    public ContextListenerWrapper() {
        super();
    }

    @Override
    public void notifyContextChange(PropertyChangeEvent evt) {
        String propertyName = evt.getPropertyName();
        Object newValue = evt.getNewValue();

        boolean tcOpened = TopComponent.Registry.PROP_TC_OPENED.equals(propertyName);
        boolean tcClosed = TopComponent.Registry.PROP_TC_CLOSED.equals(propertyName);

        if (tcOpened || tcClosed) {
            TopComponent tc = (TopComponent) newValue;
            final Lookup lookup = tc.getLookup();
            FileObject fileObject = getFileObject(lookup);
            if (null != fileObject) {

                TaskComponent taskComponent = getTaskComponentFromFileObject(fileObject);
                if (taskComponent != null) {

                    String itemPath = fileObject.getPath();
                    String projectPath = null;

                    Project project = FileOwnerQuery.getOwner(fileObject);
                    if (null != project) {
                        projectPath = project.getProjectDirectory().getPath();
                    }

                    if (tcOpened) {
                        TaskList.getDefault().addContextItem(itemPath, projectPath);
                    } else {
                        TaskList.getDefault().removeContextItem(itemPath, projectPath);
                    }
                }
            }

        }
    }

    private TaskComponent getTaskComponentFromFileObject(FileObject fileObject) {
        TaskComponent taskComponent = null;

        try {
            taskComponent = DataObject.find(fileObject).getLookup().lookup(TaskComponent.class);
        } catch (DataObjectNotFoundException ex) {
            LOGGER.log(Level.INFO, "Object does not contain TaskComponent: {0}", ex.getMessage());
        }

        return taskComponent;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        notifyContextChange(evt);
    }

    private static FileObject getFileObject(Lookup lookup) {
        FileObject fileObject = lookup.lookup(FileObject.class);
        if (null == fileObject) {
            DataObject dataObject = lookup.lookup(DataObject.class);
            if (null != dataObject) {
                fileObject = dataObject.getPrimaryFile();
            }
        }
        
        return fileObject;
    }
}
