/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task;

import com.nbtaskfocus.model.api.TaskList;
import org.openide.windows.TopComponent;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class TaskService {

    private static TaskService instance = new TaskService();
    private TaskList taskList = TaskList.getDefault();

    private TaskService() {
        TopComponent.getRegistry().addPropertyChangeListener(new ContextListenerWrapper());
    }

    public static TaskService getInstance() {
        return instance;
    }

    public void addTask(Task task) {
        addTaskToList(task);
    }
    
    public void addAndActivateTask(Task task) {
        addTaskToList(task);
        activateTask(task);
    }

    public void removeTask(Task task) {
        taskList.removeTask(task);
    }

    private void addTaskToList(Task task) {
        taskList.addTask(task);
    }

    public void activateTask(Task task) {
        task.setActive(true);
        taskList.activateTask(task);
    }

    public void deactivateTask(Task task) {
        taskList.deactivateTask(task);
    }

    public int getTaskCount() {
        int count = taskList.getCount();
        return count;
    }

    public Task getActiveTask() {
        if (taskList.getActiveTask() == Task.NULL_TASK) {
            return null;
        }

        return (Task) taskList.getActiveTask();
    }
}
